#
# spec file for package nvimpager
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nvimpager
Version:        0.13.0
Release:        1.2
Summary:        Use nvim as a pager
License:        BSD-2-Clause
Group:          Productivity/Text/Editors
URL:            https://github.com/lucc/nvimpager
Source:         https://github.com/lucc/nvimpager/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  scdoc
Requires:       lua54
Requires:       neovim >= 0.9
BuildArch:      noarch

%description
Using neovim as a pager to view man pages, git diffs, whatnot with neovim's syntax highlighting and mouse support.

%package zsh-completion
Summary:        Zsh completion for %{name}
Group:          Productivity/Text/Editors
Requires:       %{name} = %{version}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%setup -q
sed -i "s/#!\/usr\/bin\/env bash/#!\/bin\/bash/" nvimpager

%build

%install
%make_install PREFIX=%{_prefix}

%files
%license LICENSE
%doc README.md
%{_bindir}/nvimpager
%{_mandir}/man1/nvimpager.1%{?ext_man}
%dir %{_datadir}/nvimpager
%dir %{_datadir}/nvimpager/runtime
%dir %{_datadir}/nvimpager/runtime/lua
%dir %{_datadir}/nvimpager/runtime/lua/nvimpager
%{_datadir}/nvimpager/runtime/lua/nvimpager/ansi2highlight.lua
%{_datadir}/nvimpager/runtime/lua/nvimpager/cat.lua
%{_datadir}/nvimpager/runtime/lua/nvimpager/init.lua
%{_datadir}/nvimpager/runtime/lua/nvimpager/options.lua
%{_datadir}/nvimpager/runtime/lua/nvimpager/pager.lua
%{_datadir}/nvimpager/runtime/lua/nvimpager/util.lua

%files zsh-completion
%license LICENSE
%{_datadir}/zsh

%changelog
* Tue May 21 2024 Michael Vetter <mvetter@suse.com>
- Update to 0.13.0:
  Major changes:
  * Accept - as stdin in any argument position
  Breaking changes:
  * Change order of nvimpager's and user supplied options
  Changes:
  * Deactivate some tests for neovim v0.10
  * Improve documentation in lua code, make it ldoc compatible
  * Add darwin packages to flake
  * Use neovim overlay flake instead of neovim flake for nightly neovim
  * Add tests with nvim's internal assert functions
  * Fix detection of empty buffers (neovim/neovim#25369)
  * Refactor process detection (neovim/neovim#23122)
* Wed May 10 2023 Michael Vetter <mvetter@suse.com>
- Update to 0.12.0:
  * Use upstream support for $NVIM_APPNAME
  * Conceal \e[K escape sequences in pager mode
  * Fix man page detection for empty lines
  * makefile: Split install rule, supporting installation without man
  * Move unit tests to extra file
  * Handle all test excludes via busted tags
  * Use native neovim function to get parsed listchar
  * Filter out broken tests in CI
  * Run tests in CI with neovim from the official appimages
  * Set LUA_PATH for the tests in the makefile
  * Split code into modules
  * Add helper function to better detect man pages
* Tue Oct 18 2022 Michael Vetter <mvetter@suse.com>
- Update to 0.11.0:
  Breaking changes:
  * require neovim >= 0.7.2
  * Rename env var NVIM to NVIMPAGER_NVIM
  * Improve version number format to better conform to SemVer
  * Only use buffer local maps
  * Keep input file order when reading from stdin and files
  Major changes:
  * Allow lua init file (#64[1])
  * Implement follow mode (#21[2])
  * Add git_colors option to use colors from git instead of internal syntax (#68[3])
  * Use :Man! to set filetype in python docs
  * Use exec to start nvim, delete tempfile for stdin from nvim and set buftype=nofile
  * Rename execed nvim process to "nvimpager"
  * Remove extra redirect from tty
* Thu Aug 18 2022 Michael Vetter <mvetter@suse.com>
- Initial package of nvimpager 0.10.4 for openSUSE
